# unitorch.cli.models.visualbert

## VisualBertProcessor

!!! tip
    **`core/process/visualbert`** is the section for configuration of VisualBertProcessor.

::: unitorch.cli.models.visualbert.VisualBertProcessor

## VisualBertForClassification

!!! tip
    **`core/model/classification/visualbert`** is the section for configuration of VisualBertForClassification.

::: unitorch.cli.models.visualbert.VisualBertForClassification

## VisualBertForPretrain

!!! tip
    **`core/model/pretrain/visualbert`** is the section for configuration of VisualBertForPretrain.

::: unitorch.cli.models.visualbert.VisualBertForPretrain
